@@ -6,7 +6,7 @@ module Rake
   include Test::Unit::Assertions
 
   def run_tests(pattern='test/test*.rb', log_enabled=false)
-    FileList.glob(pattern).each { |fn|
+    FileList.glob(pattern).each do |fn|
       $stderr.puts fn if log_enabled
       begin
         require fn
@@ -15,7 +15,7 @@ module Rake
         $stderr.puts ex.backtrace
         assert false
       end
-    }
+    end
   end
 
   extend self
