@@ -3,8 +3,8 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION == "2.1.0" or
-    raise "ruby lib version (2.1.0) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "2.1.2" or
+    raise "ruby lib version (2.1.2) doesn't match executable version (#{RUBY_VERSION})"
 
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.1/sparc-openbsd")
   DESTDIR = '' unless defined? DESTDIR
@@ -13,7 +13,7 @@ module RbConfig
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "1"
   CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "0"
+  CONFIG["PATCHLEVEL"] = "95"
   CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
@@ -36,7 +36,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--program-suffix=21' '--with-soname=ruby21' '--with-ruby-version=minor' '--enable-pthread' '--enable-ipv6' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-tcllib=tcl85' '--with-tklib=tk85' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
+  CONFIG["configure_args"] = " '--program-suffix=21' '--with-soname=ruby21' '--with-ruby-version=minor' '--enable-pthread' '--enable-ipv6' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-tcllib=tcl85' '--with-tklib=tk85' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -fstack-shuffle -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -fstack-shuffle -pipe'"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
   CONFIG["vendordir"] = "$(rubylibprefix)/vendor_ruby"
@@ -167,33 +167,33 @@ module RbConfig
   CONFIG["EGREP"] = "/usr/bin/egrep"
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["CPP"] = "$(CC) -E"
-  CONFIG["CXXFLAGS"] = "-O2 -pipe"
+  CONFIG["CXXFLAGS"] = "-O2 -fstack-shuffle -pipe"
   CONFIG["CXX"] = "c++"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -fstack-protector -Wl,-E"
-  CONFIG["CFLAGS"] = "-O2 -pipe -fPIC"
+  CONFIG["CFLAGS"] = "-O2 -fstack-shuffle -pipe -fPIC"
   CONFIG["CC"] = "cc"
   CONFIG["NACL_SDK_VARIANT"] = ""
   CONFIG["NACL_SDK_ROOT"] = ""
   CONFIG["NACL_TOOLCHAIN"] = ""
-  CONFIG["target_os"] = "openbsd5.5"
+  CONFIG["target_os"] = "openbsd5.6"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "sparc"
-  CONFIG["target"] = "sparc-unknown-openbsd5.5"
-  CONFIG["host_os"] = "openbsd5.5"
+  CONFIG["target"] = "sparc-unknown-openbsd5.6"
+  CONFIG["host_os"] = "openbsd5.6"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "sparc"
-  CONFIG["host"] = "sparc-unknown-openbsd5.5"
+  CONFIG["host"] = "sparc-unknown-openbsd5.6"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd5.5"
+  CONFIG["build_os"] = "openbsd5.6"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "sparc"
-  CONFIG["build"] = "sparc-unknown-openbsd5.5"
-  CONFIG["RUBY_RELEASE_DATE"] = "2013-12-25"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.1.0"
+  CONFIG["build"] = "sparc-unknown-openbsd5.6"
+  CONFIG["RUBY_RELEASE_DATE"] = "2014-05-08"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.1.2"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
